package com.dgtly.wxportal.mapper;

import com.dgtly.wxportal.domain.WxBanner;
import java.util.List;

/**
 * 企业微信门户首页banner图Mapper接口
 * 
 * @author qxp
 * @date 2020-06-23
 */
public interface WxBannerMapper 
{
    /**
     * 查询企业微信门户首页banner图
     * 
     * @param bannerId 企业微信门户首页banner图ID
     * @return 企业微信门户首页banner图
     */
    public WxBanner selectWxBannerById(Long bannerId);

    /**
     * 查询企业微信门户首页banner图列表
     * 
     * @param wxBanner 企业微信门户首页banner图
     * @return 企业微信门户首页banner图集合
     */
    public List<WxBanner> selectWxBannerList(WxBanner wxBanner);

    /**
     * 新增企业微信门户首页banner图
     * 
     * @param wxBanner 企业微信门户首页banner图
     * @return 结果
     */
    public int insertWxBanner(WxBanner wxBanner);

    /**
     * 修改企业微信门户首页banner图
     * 
     * @param wxBanner 企业微信门户首页banner图
     * @return 结果
     */
    public int updateWxBanner(WxBanner wxBanner);

    /**
     * 删除企业微信门户首页banner图
     * 
     * @param bannerId 企业微信门户首页banner图ID
     * @return 结果
     */
    public int deleteWxBannerById(Long bannerId);

    /**
     * 批量删除企业微信门户首页banner图
     * 
     * @param bannerIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteWxBannerByIds(String[] bannerIds);
}
